@@ -23,7 +23,7 @@ class NumbersEntry(EntryBlock):
             'value': {
                 'number': 90,
                 'unit': '%',
-                'content': {'value': self.mocker.p},
+                'content': {'value': self.p},
             }
         }
 
